FlutterSplit class

Constructors

FlutterSplit()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
getTreatment(String key, Map<String, dynamic> attr) → Future<String?>
getTreatments(List<String> keys, Map<String, dynamic> attr) → Future<Map<String, String?>>
getTreatmentsWithConfig(List<String> keys, Map<String, dynamic> attr) → Future<Map<String, SplitResult>>
getTreatmentWithConfig(String key, Map<String, dynamic> attr) → Future<SplitResult?>
initializeSdk(String appKey, String userId) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
trackEvent(String eventType, String trafficType, Map<String, dynamic> props) → Future<bool?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited